# About Code Video Generator

Code Video Generator is Python library for [Manim](https://github.com/manimcommunity/manim) for generating code
 walkthrough videos.
 
It is built and maintained by the [Sleuth](https://sleuth.io) team.